body {
        background: white;
        color: black;
}

h1 {
        background: black;
        color: white;
        padding: 10pt;
        font-size: 24pt;
        font-family: Arial, Helvetica;
}

h2 {
        background: #AAAAFF;
        padding: 5pt;
        font-size: 16pt;
        font-family: Arial, Helvetica;
        text-align: left;
}

h3 {
        border-style: solid;
        border-width: 0pt;
        border-top-width: 1pt;
        border-bottom-width: 1pt;
}

p {
        margin-left: 10pt;
        text-align: justify;
}

div.sect1 p {
        margin-left: 10pt;
        margin-right: 10pt;
}

p.title {
        text-decoration: underline;
}

div.toc p {
        text-decoration: underline;
}

pre {
        background: #DDDDDD;
        padding: 10pt;
        margin-left: 50pt;
        margin-right: 50pt;
        color: #0000AA;
}

pre.screen {
        font-style: italic;
}

dt {
        margin-left: 20pt;
}

tt.filename {
        color: #AA0000;
}

div.note p {
        padding: 5pt;
        background: #EEEECC;
}

div.warning p {
        padding: 5pt;
        background: #EECCCC;
}

div.funcenv p {
        padding: 5pt;
        margin-left: 50pt;
        margin-right: 50pt;
        background: #CCEECC;
}